const { Container, DependencyInjector } = require('flitter-di')
const { test_connect } = require('../common')
const { expect } = require('chai')
const { MongoClient, ObjectId } = require('mongodb')
const uuid = require('uuid/v4')

describe('embedded model storage and retrieval', function() {
    const Connection = require('../../src/services/Connection')
    const Model = require('../../src/model/Model')
    const di = new DependencyInjector(new Container({ scaffold: Connection }))
    class TestModel extends Model {
        static collection = uuid()

        static get schema() {
            return {
                name: String,
                number: Number,
            }
        }
    }
    class TestGroupModel extends Model {
        static collection = uuid()

        static get schema() {
            return {
                group_name: String,
                tests: [TestModel],
            }
        }
    }
    di.make(TestModel)
    di.make(TestGroupModel)

    before(async function() {
        await di.service('scaffold').open(test_connect)
    })

    after(function() {
        di.service('scaffold').close()
    })

    it('should allow saving of embedded models', async function() {
        const test_1 = new TestModel({ number: 1, name: 'test_1' })
        const test_2 = new TestModel({ number: 2, name: 'test_2' })
        const group = new TestGroupModel({group_name: 'test test group', tests: [test_1, test_2]})

        const save_group = await group.save()
        expect(save_group.tests).to.be.eql(group.tests)

        const direct_tests = await TestModel.find()
        expect(direct_tests.length).to.be.equal(0)
    })

    it('should allow retrieval of embedded models', async function() {
        const group = await TestGroupModel.findOne({group_name: 'test test group'})
        expect(group.tests).to.be.an('array')
        expect(group.tests.length).to.be.equal(2)
        expect(group.tests[0]).to.be.an.instanceof(TestModel)
        expect(group.tests[0].number).to.be.equal(1)
        expect(group.tests[0].name).to.be.equal('test_1')
        expect(group.tests[1]).to.be.an.instanceof(TestModel)
        expect(group.tests[1].number).to.be.equal(2)
        expect(group.tests[1].name).to.be.equal('test_2')
    })
})
